#! /usr/bin/perl
#
# COPYING
# Liquid Font Family
# Copyright (C) 2009 Henrik Theiling
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# SYNOPOSIS
# Makes private byte patterns for text-driven graphics mode.

use strict;
use warnings;

use constant BLOCK => 0xf0500;

my $mode= 'unidata';

for my $arg (@ARGV) {
    if ($arg =~ /^-+unidata/) {
        $mode= 'unidata';
    }
    elsif ($arg =~ /^-+ftx/) {
        $mode= 'ftx';
    }
    else {
        die "Error: unrecognised option: $arg\n";
    }
}

if ($mode eq 'unidata') {
    for my $b (0..255) {
        printf "%04X;BYTE PATTERN %s;So;0;L;;;;;N;;;;;\n",
            BLOCK + $b,
            ($b ?
                "DOTS-".join('',
                    map {
                        my $i= $_;
                        (($b & (1 << $i)) ? ($i+1) : '')
                    }
                    0..7
                )
            :   "BLANK"
            );
    }
}
elsif ($mode eq 'ftx') {
    for my $i (0..255) {
        printf ":0x%04x\n", BLOCK + $i;
        my $s=
           "___|__\n".
           "...0..\n".
           "...1..\n".
           "...2..\n".
           "...3..\n".
           "...4..\n".
           "...5..\n".
           "...6..\n".
           "...7..\n";
        $s=~ s/(\d)/($i & (1 << $1)) ? '#' : '.'/gsex;
        print  "-space 0\n";
        print "$s";
        print  "\n";
    }
}
else {
    die "Error: unknown mode $mode\n";
}
